@@ -1,18 +1,18 @@
-BEGIN { $INC{$_} = 1 for qw(MP3/M3U/Parser.pm MP3/M3U/Parser/Constants.pm MP3/M3U/Parser/Dummy.pm MP3/M3U/Parser/Export.pm); }
+BEGIN { $INC{$_} = 1 for qw(MP3/M3U/Parser.pm MP3/M3U/Parser/Dummy.pm MP3/M3U/Parser/Export.pm MP3/M3U/Parser/Constants.pm); }
 package MP3::M3U::Parser;
 sub ________monolith {}
-package MP3::M3U::Parser::Constants;
-sub ________monolith {}
 package MP3::M3U::Parser::Dummy;
 sub ________monolith {}
 package MP3::M3U::Parser::Export;
 sub ________monolith {}
 package MP3::M3U::Parser::Constants;
+sub ________monolith {}
+package MP3::M3U::Parser::Constants;
 use strict;
 use warnings;
 use vars qw( $VERSION @EXPORT @EXPORT_OK %EXPORT_TAGS $OID );
 
-$VERSION = '2.30';
+$VERSION = '2.31';
 
 # Data table key map
 use constant PATH    => $OID++;
@@ -72,7 +72,7 @@ use Carp qw( croak );
 use MP3::M3U::Parser::Constants;
 use MP3::M3U::Parser::Dummy;
 
-$VERSION = '2.30';
+$VERSION = '2.31';
 
 my %DEFAULT = (
     format    => 'html',
@@ -411,7 +411,7 @@ use strict;
 use warnings;
 use vars qw( $VERSION );
 
-$VERSION = '2.30';
+$VERSION = '2.31';
 
 package MP3::M3U::Parser;
 use strict;
@@ -421,7 +421,7 @@ use base qw( MP3::M3U::Parser::Export );
 use Carp qw( croak );
 use MP3::M3U::Parser::Constants;
 
-$VERSION = '2.30';
+$VERSION = '2.31';
 
 my %LOADED;
 
@@ -788,6 +788,8 @@ __END__
 
 =pod
 
+=encoding utf8
+
 =head1 NAME
 
 MP3::M3U::Parser - MP3 playlist parser.
@@ -835,8 +837,8 @@ generated with an automatic build tool. If you experience problems
 with this version, please install and use the supported standard
 version. This version is B<NOT SUPPORTED>.
 
-This document describes version C<2.30> of C<MP3::M3U::Parser>
-released on C<30 May 2010>.
+This document describes version C<2.31> of C<MP3::M3U::Parser>
+released on C<9 September 2012>.
 
 B<MP3::M3U::Parser> is a parser for M3U mp3 playlist files. It also 
 parses the EXTINF lines (which contains id3 song name and time) if 
@@ -893,6 +895,9 @@ path. Also, you "must" ignore the drive table contents which will still contain
 a possibly wrong value; C<export> does take the drive letters from the drive
 tables. So, you can not use the drive area in the exported xml (for example).
 
+B<Note:> you probably want to set this parameter to 'C<asis>' on a non-Windows
+machine.
+
 =item C<-overwrite>
 
 Same as the C<-overwrite> option in L<export|/export> but C<new> sets this 
@@ -1147,10 +1152,6 @@ you can have an easy maintained archive.
 HTML and XML escaping is limited to these characters: 
 E<amp> E<quot> E<lt> E<gt> B<unless> you have C<HTML::Entities> installed.
 
-=head1 BUGS
-
-Contact the author if you find any bugs.
-
 =head1 SEE ALSO
 
 L<HTML::Entities>.
@@ -1161,12 +1162,11 @@ Burak Gursoy <burak@cpan.org>.
 
 =head1 COPYRIGHT
 
-Copyright 2003 - 2010 Burak Gursoy. All rights reserved.
+Copyright 2003 - 2012 Burak Gursoy. All rights reserved.
 
 =head1 LICENSE
 
-This library is free software; you can redistribute it and/or modify 
-it under the same terms as Perl itself, either Perl version 5.10.1 or, 
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself, either Perl version 5.12.3 or,
 at your option, any later version of Perl 5 you may have available.
-
 =cut
